;+
;
; @file_comments
; compute the latitudes of the n80 gaussian grid. See:
; <a href="http://www.ecmwf.int/products/data/technical/gaussian/n80FIS.html">Gaussian 80</a>
;
; @categories
; Grid
;
; @examples
; IDL> lat=n80gaussian()
;
; @returns
; a 1d array
;
; @history
;      Sebastien Masson (smasson\@lodyc.jussieu.fr)
;      June 2004
;
; @version
; $Id$
;
;-
FUNCTION n80gaussian
;
  compile_opt idl2, strictarrsubs
;
;          latitude   reduced     regular  latitude
;           number     points      points
;          -------    -------     -------  --------
  n80 = [     1,         18,        320,  89.14152, $
              2,         25,        320,  88.02943, $
              3,         36,        320,  86.91077, $
              4,         40,        320,  85.79063, $
              5,         45,        320,  84.66992, $
              6,         54,        320,  83.54895, $
              7,         60,        320,  82.42782, $
              8,         64,        320,  81.30659, $
              9,         72,        320,  80.18531, $
              10,         72,        320,  79.06398, $
              11,         80,        320,  77.94262, $
              12,         90,        320,  76.82124, $
              13,         96,        320,  75.69984, $
              14,        100,        320,  74.57843, $
              15,        108,        320,  73.45701, $
              16,        120,        320,  72.33558, $
              17,        120,        320,  71.21414, $
              18,        128,        320,  70.09269, $
              19,        135,        320,  68.97124, $
              20,        144,        320,  67.84978, $
              21,        144,        320,  66.72833, $
              22,        150,        320,  65.60686, $
              23,        160,        320,  64.48540, $
              24,        160,        320,  63.36393, $
              25,        180,        320,  62.24246, $
              26,        180,        320,  61.12099, $
              27,        180,        320,  59.99952, $
              28,        192,        320,  58.87804, $
              29,        192,        320,  57.75657, $
              30,        200,        320,  56.63509, $
              31,        200,        320,  55.51361, $
              32,        216,        320,  54.39214, $
              33,        216,        320,  53.27066, $
              34,        216,        320,  52.14917, $
              35,        225,        320,  51.02769, $
              36,        225,        320,  49.90621, $
              37,        240,        320,  48.78473, $
              38,        240,        320,  47.66325, $
              39,        240,        320,  46.54176, $
              40,        256,        320,  45.42028, $
              41,        256,        320,  44.29879, $
              42,        256,        320,  43.17731, $
              43,        256,        320,  42.05582, $
              44,        288,        320,  40.93434, $
              45,        288,        320,  39.81285, $
              46,        288,        320,  38.69137, $
              47,        288,        320,  37.56988, $
              48,        288,        320,  36.44839, $
              49,        288,        320,  35.32691, $
              50,        288,        320,  34.20542, $
              51,        288,        320,  33.08393, $
              52,        288,        320,  31.96244, $
              53,        300,        320,  30.84096, $
              54,        300,        320,  29.71947, $
              55,        300,        320,  28.59798, $
              56,        300,        320,  27.47649, $
              57,        320,        320,  26.35500, $
              58,        320,        320,  25.23351, $
              59,        320,        320,  24.11203, $
              60,        320,        320,  22.99054, $
              61,        320,        320,  21.86905, $
              62,        320,        320,  20.74756, $
              63,        320,        320,  19.62607, $
              64,        320,        320,  18.50458, $
              65,        320,        320,  17.38309, $
              66,        320,        320,  16.26160, $
              67,        320,        320,  15.14011, $
              68,        320,        320,  14.01862, $
              69,        320,        320,  12.89713, $
              70,        320,        320,  11.77564, $
              71,        320,        320,  10.65415, $
              72,        320,        320,   9.53266, $
              73,        320,        320,   8.41117, $
              74,        320,        320,   7.28968, $
              75,        320,        320,   6.16819, $
              76,        320,        320,   5.04670, $
              77,        320,        320,   3.92521, $
              78,        320,        320,   2.80372, $
              79,        320,        320,   1.68223, $
              80,        320,        320,   0.56074]
;
  n80 = reform(n80, 4, 80, /over)
  n80 = reform(n80[3, *], /over)
  n80 = [n80, -reverse(n80)]

  return, n80
end
